"""
This folder contains scripts that aren’t integral to the workings of the package.
It’s very useful for holding the scripts that actually do something useful using your package.
For example, if your package is ‘python-polygons’ a bin script might be ‘generate-triangle’.
If your package is a web application, a bin script might be ‘run-dev-server’.
"""

#!/usr/bin/env python

import random
print(random.randint(1,99999999))
